PathSig

Struct PathSig 

pub struct PathSig<const D: usize>
where U<D>: EfdDim<D>,
{ pub curve: Vec<[f64; D]>, pub t: Vec<f64>, pub geo: GeoVar<Rot<D>, D>, }
Path signature with the target position.

Use to present an “original path”. Can be compared with Efd by Efd::err_sig().

See also get_norm_t().

Fields

curve: Vec<[f64; D]>

Normalized curve

t: Vec<f64>

Normalized time parameters

geo: GeoVar<Rot<D>, D>

Geometric variables

Implementations

Source

impl<const D: usize> PathSig<D>
where U<D>: EfdDim<D>,

pub fn new<C>(curve: C, is_open: bool) -> Self
where C: Curve<D>,

Get the time parameter t of each point coordinate and the normalized geometric variables of the curve.

This function is faster than building Efd since it only calculates two harmonics.

let curve = [[0., 0.], [1., 0.], [1., 1.], [0., 1.]];
let sig = efd::PathSig::new(curve, true);
pub fn as_t(&self) -> &[f64]

Get the reference of normalized time parameters.

pub fn as_geo(&self) -> &GeoVar<Rot<D>, D>

Get the reference of geometric variables.