pub struct PathSig<const D: usize>{
pub curve: Vec<[f64; D]>,
pub t: Vec<f64>,
pub geo: GeoVar<Rot<D>, D>,
}Expand description
Path signature with the target position.
Use to present an “original path”. Can be compared with Efd by
Efd::err_sig().
See also get_norm_t().
Fields
curve: Vec<[f64; D]>Normalized curve
t: Vec<f64>Normalized time parameters
geo: GeoVar<Rot<D>, D>Geometric variables
Implementations
Sourceimpl<const D: usize> PathSig<D>
impl<const D: usize> PathSig<D>
Sourcepub fn new<C>(curve: C, is_open: bool) -> Selfwhere
C: Curve<D>,
pub fn new<C>(curve: C, is_open: bool) -> Selfwhere
C: Curve<D>,
Get the time parameter t of each point coordinate and the normalized
geometric variables of the curve.
This function is faster than building Efd since it only calculates
two harmonics.
let curve = [[0., 0.], [1., 0.], [1., 1.], [0., 1.]];
let sig = efd::PathSig::new(curve, true);Trait Implementations